pub enum LightSectionData {
Homogeneous(u8),
Packed(Box<[u8; 2048]>),
}Expand description
Storage representation for one present light section.
Variants
Homogeneous(u8)
One light value applies to the whole section.
Packed(Box<[u8; 2048]>)
Vanilla low-nibble-first packed light values.
Implementations
Sourceimpl LightSectionData
impl LightSectionData
Sourcepub const fn homogeneous(value: u8) -> Self
pub const fn homogeneous(value: u8) -> Self
Creates homogeneous section data, masking to the vanilla light range.
Sourcepub fn get(&self, x: usize, y: usize, z: usize) -> u8
pub fn get(&self, x: usize, y: usize, z: usize) -> u8
Returns the light value at local section coordinates.
Sourcepub fn set(&mut self, x: usize, y: usize, z: usize, value: u8)
pub fn set(&mut self, x: usize, y: usize, z: usize, value: u8)
Sets the light value at local section coordinates.
Sourcepub const fn is_homogeneous(&self) -> bool
pub const fn is_homogeneous(&self) -> bool
Returns true when this section is represented by one homogeneous value.
Sourcepub const fn is_empty(&self) -> bool
pub const fn is_empty(&self) -> bool
Returns true when this section is the visible empty section state.
Sourcepub fn is_all_zero(&self) -> bool
pub fn is_all_zero(&self) -> bool
Returns true when every packed light value is zero.
Sourcepub fn to_bytes(&self) -> Box<[u8; 2048]>
pub fn to_bytes(&self) -> Box<[u8; 2048]>
Returns packed bytes without changing the section representation.
const fn get_from_packed(data: &[u8; 2048], index: usize) -> u8
const fn set_in_packed(data: &mut [u8; 2048], index: usize, value: u8)
const fn index(x: usize, y: usize, z: usize) -> usize
const fn pack_filled(value: u8) -> u8