ChunkLightLayerStorage

Struct ChunkLightLayerStorage 

pub struct ChunkLightLayerStorage {
    layer: LightLayer,
    range: LightSectionRange,
    chunk_section_count: usize,
    sections: Box<[LightSection]>,
    emptiness_map: Option<Box<[bool]>>,
}
Per-layer chunk-owned light storage.

Fields

layer: LightLayerrange: LightSectionRangechunk_section_count: usizesections: Box<[LightSection]>emptiness_map: Option<Box<[bool]>>

Implementations

Source

impl ChunkLightLayerStorage

pub fn new( layer: LightLayer, range: LightSectionRange, chunk_section_count: usize, ) -> Self

Creates missing light sections for every light section in a chunk.

pub const fn layer(&self) -> LightLayer

Returns this storage’s light layer.

pub const fn range(&self) -> LightSectionRange

Returns the vertical light-section range.

pub fn sections(&self) -> &[LightSection]

Returns all chunk light sections.

pub fn sections_mut(&mut self) -> &mut [LightSection]

Returns all chunk light sections mutably.

pub const fn chunk_section_count(&self) -> usize

Returns the number of real chunk sections tracked by the emptiness map.

pub fn section(&self, section_y: i32) -> Option<&LightSection>

Returns a light section for a section Y coordinate.

pub fn section_mut(&mut self, section_y: i32) -> Option<&mut LightSection>

Returns a mutable light section for a section Y coordinate.

pub fn emptiness_map(&self) -> Option<&[bool]>

Returns the current section emptiness map, if known.

pub fn section_empty(&self, section_y: i32) -> Option<bool>

Returns the known emptiness for one real chunk section Y.

pub(crate) fn highest_non_empty_section_y(&self) -> Option<i32>

Returns the highest real chunk section known to contain blocks.

pub fn set_emptiness_map( &mut self, emptiness_map: Box<[bool]>, ) -> Result<(), ChunkLightEmptinessMapLengthError>

Replaces the section emptiness map.

pub fn refresh_emptiness_map_from_sections( &mut self, sections: &Sections, ) -> Result<(), ChunkLightEmptinessMapLengthError>

Replaces the section emptiness map from current section counters.

pub fn set_section_empty(&mut self, section_y: i32, empty: bool) -> Option<bool>

Updates one known section emptiness entry, returning the previous value.

pub(crate) fn fill_loaded_missing_sky_sections_below_data_with_zero(&mut self)

Applies ScalableLux’s loaded-sky-data normalization.

pub fn get_light_value(&self, block_pos: BlockPos) -> u8

Returns the visible light value for one block position.

fn get_block_light_value(&self, block_pos: BlockPos) -> u8

fn get_sky_light_value(&self, block_pos: BlockPos) -> u8

fn visible_section_value(&self, block_pos: BlockPos) -> Option<u8>

fn chunk_section_index(&self, section_y: i32) -> Option<usize>